@@ -1,3 +1,5 @@
+use std::fmt::format;
+
 use pyo3::prelude::*;
 
 /// Formats the sum of two numbers as string.
@@ -22,10 +24,18 @@ fn fibonacci(n: u64) -> PyResult<u64> {
     Ok(b)
 }
 
+/// 一个hello world test
+#[pyfunction]
+fn hello_world(name: String) -> PyResult<String> {
+    let result = format!("Hello, {}.I'm LiXin.It's nice to see you again",name);
+    Ok(result)
+}
+
 /// A Python module implemented in Rust.
 #[pymodule]
 fn rust_python_lib(m: &Bound<'_, PyModule>) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(sum_as_string, m)?)?;
-    m.add_function(wrap_pyfunction!(fibonacci,m)?)?;
+    m.add_function(wrap_pyfunction!(fibonacci, m)?)?;
+    m.add_function(wrap_pyfunction!(hello_world, m)?)?;
     Ok(())
 }
